@@ -1,57 +1,31 @@
 /*
  * Copyright 2005 - 2015  Zarafa B.V. and its licensors
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation with the following
- * additional terms according to sec. 7:
- * 
- * "Zarafa" is a registered trademark of Zarafa B.V.
- * The licensing of the Program under the AGPL does not imply a trademark 
- * license. Therefore any rights, title and interest in our trademarks 
- * remain entirely with us.
- * 
- * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
- * in connection with Propagation and certain other acts regarding the Program.
- * In any case, if you propagate an unmodified version of the Program you are
- * allowed to use the term "Zarafa" to indicate that you distribute the Program.
- * Furthermore you may use our trademarks where it is necessary to indicate the
- * intended purpose of a product or service provided you use it in accordance
- * with honest business practices. For questions please contact Zarafa at
- * trademark@zarafa.com.
+ * as published by the Free Software Foundation.
  *
- * The interactive user interface of the software displays an attribution 
- * notice containing the term "Zarafa" and/or the logo of Zarafa. 
- * Interactive user interfaces of unmodified and modified versions must 
- * display Appropriate Legal Notices according to sec. 5 of the GNU Affero 
- * General Public License, version 3, when you propagate unmodified or 
- * modified versions of the Program. In accordance with sec. 7 b) of the GNU 
- * Affero General Public License, version 3, these Appropriate Legal Notices 
- * must retain the logo of Zarafa or display the words "Initial Development 
- * by Zarafa" if the display of the logo is not reasonably feasible for
- * technical reasons.
- * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
- *  
+ *
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifndef UTIL_H
 #define UTIL_H
 
-#include "zcdefs.h"
+#include <zarafa/zcdefs.h>
 #include <mapix.h>
 #include <edkmdb.h>
 #include <string>
 
-#include "ECDefs.h"
+#include <zarafa/ECDefs.h>
 
-#include "ustringutil.h"
+#include <zarafa/ustringutil.h>
 
 class ECLogger;
 
@@ -59,7 +33,7 @@ class ECLogger;
  * This class only exists to satisfy the %extend directive in swig/libcommon.i.
  * It screams for replacement with a namespace Util {}
  */
-class Util _final {
+class Util _zcp_final {
 	public:
 	static HRESULT	HrAddToPropertyArray(const SPropValue *lpSrc, ULONG cValues, const SPropValue *lpAdd, SPropValue **lppDest, ULONG *cDestValues);
 	static HRESULT	HrMergePropertyArrays(const SPropValue *lpSrc, ULONG cValues, const SPropValue *lpAdds, ULONG cAddValues, SPropValue **lppDest, ULONG *cDestValues);
@@ -145,7 +119,7 @@ class Util _final {
 	static HRESULT HrCopyIMAPData(LPMESSAGE lpSrcMsg, LPMESSAGE lpDstMsg);
 	static HRESULT HrDeleteIMAPData(LPMESSAGE lpMsg);
 
-	static HRESULT HrGetQuotaStatus(IMsgStore *lpMsgStore, LPECQUOTA lpsQuota, LPECQUOTASTATUS *lppsQuotaStatus);
+	static HRESULT HrGetQuotaStatus(IMsgStore *lpMsgStore, ECQUOTA *lpsQuota, ECQUOTASTATUS **lppsQuotaStatus);
 
 	static HRESULT HrDeleteResidualProps(LPMESSAGE lpDestMsg, LPMESSAGE lpSourceMsg, LPSPropTagArray lpsValidProps);
 	static HRESULT ValidMapiPropInterface(LPCIID lpInterface);
