@@ -1,50 +1,24 @@
 /*
  * Copyright 2005 - 2015  Zarafa B.V. and its licensors
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation with the following
- * additional terms according to sec. 7:
- * 
- * "Zarafa" is a registered trademark of Zarafa B.V.
- * The licensing of the Program under the AGPL does not imply a trademark 
- * license. Therefore any rights, title and interest in our trademarks 
- * remain entirely with us.
- * 
- * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
- * in connection with Propagation and certain other acts regarding the Program.
- * In any case, if you propagate an unmodified version of the Program you are
- * allowed to use the term "Zarafa" to indicate that you distribute the Program.
- * Furthermore you may use our trademarks where it is necessary to indicate the
- * intended purpose of a product or service provided you use it in accordance
- * with honest business practices. For questions please contact Zarafa at
- * trademark@zarafa.com.
+ * as published by the Free Software Foundation.
  *
- * The interactive user interface of the software displays an attribution 
- * notice containing the term "Zarafa" and/or the logo of Zarafa. 
- * Interactive user interfaces of unmodified and modified versions must 
- * display Appropriate Legal Notices according to sec. 5 of the GNU Affero 
- * General Public License, version 3, when you propagate unmodified or 
- * modified versions of the Program. In accordance with sec. 7 b) of the GNU 
- * Affero General Public License, version 3, these Appropriate Legal Notices 
- * must retain the logo of Zarafa or display the words "Initial Development 
- * by Zarafa" if the display of the logo is not reasonably feasible for
- * technical reasons.
- * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
- *  
+ *
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifndef ZARAFACODE_H
 #define ZARAFACODE_H
 
-#include "platform.h"
+#include <zarafa/platform.h>
 
 #define MAKE_ZARAFA_SCODE(sev,code) ( (((unsigned int)(sev)<<31) | ((unsigned int)(code))) )
 #define MAKE_ZARAFA_E( err ) (MAKE_ZARAFA_SCODE( 1, err ))
@@ -113,8 +87,8 @@ typedef unsigned int ECRESULT;
 #define ZARAFA_OBJTYPE_MESSAGE			5
 
 // Sessions
-#define ECSESSIONID	uint64_t
-#define ECSESSIONGROUPID uint64_t
+typedef uint64_t ECSESSIONID;
+typedef uint64_t ECSESSIONGROUPID;
 
 #define EC_NOTIFICATION_CHECK_FREQUENTY		(1000*2)
 #define EC_NOTIFICATION_CLOSE_TIMEOUT		(1000)
@@ -144,6 +118,7 @@ typedef unsigned int ECRESULT;
 
 // Property under which to store the search criteria for search folders
 #define PR_EC_SEARCHCRIT	PROP_TAG(PT_STRING8, 0x6706)
+#define PR_EC_SUGGESTION	PROP_TAG(PT_UNICODE, 0x6707)
 
 // create 200 directories for non-database attachments
 #define ATTACH_PATHDEPTH_LEVEL1 10
