@@ -1,60 +1,34 @@
 /*
  * Copyright 2005 - 2015  Zarafa B.V. and its licensors
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation with the following
- * additional terms according to sec. 7:
- * 
- * "Zarafa" is a registered trademark of Zarafa B.V.
- * The licensing of the Program under the AGPL does not imply a trademark 
- * license. Therefore any rights, title and interest in our trademarks 
- * remain entirely with us.
- * 
- * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
- * in connection with Propagation and certain other acts regarding the Program.
- * In any case, if you propagate an unmodified version of the Program you are
- * allowed to use the term "Zarafa" to indicate that you distribute the Program.
- * Furthermore you may use our trademarks where it is necessary to indicate the
- * intended purpose of a product or service provided you use it in accordance
- * with honest business practices. For questions please contact Zarafa at
- * trademark@zarafa.com.
+ * as published by the Free Software Foundation.
  *
- * The interactive user interface of the software displays an attribution 
- * notice containing the term "Zarafa" and/or the logo of Zarafa. 
- * Interactive user interfaces of unmodified and modified versions must 
- * display Appropriate Legal Notices according to sec. 5 of the GNU Affero 
- * General Public License, version 3, when you propagate unmodified or 
- * modified versions of the Program. In accordance with sec. 7 b) of the GNU 
- * Affero General Public License, version 3, these Appropriate Legal Notices 
- * must retain the logo of Zarafa or display the words "Initial Development 
- * by Zarafa" if the display of the logo is not reasonably feasible for
- * technical reasons.
- * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
- *  
+ *
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifndef mapi_object_ptr_INCLUDED
 #define mapi_object_ptr_INCLUDED
 
-#include "zcdefs.h"
+#include <zarafa/zcdefs.h>
 #include <algorithm>
 #include <mapiutil.h>
-#include "IECUnknown.h"
-#include "ECTags.h"
-#include "ECGuid.h"
-#include "mapi_memory_ptr.h"
+#include <zarafa/IECUnknown.h>
+#include <zarafa/ECTags.h>
+#include <zarafa/ECGuid.h>
+#include <zarafa/mapi_ptr/mapi_memory_ptr.h>
 
 // http://tinyurl.com/ydb363n
 template<typename BaseT, typename DerivedT>
-class Conversion _final {
+class Conversion _zcp_final {
     static DerivedT& derived();
     static char test(const BaseT&);
     static char (&test(...))[2];
@@ -72,7 +46,7 @@ class mapi_object_proxy<IUnknown, IID_IUnknown>;
 
 
 template<typename _T, REFIID _R = GUID_NULL>
-class mapi_object_ptr _final {
+class mapi_object_ptr _zcp_final {
 public:
 	static const IID				iid;
 	typedef _T						value_type;
@@ -243,7 +217,7 @@ friend class mapi_object_proxy<_T, _R>;
 
 
 template<typename _T, REFIID _R>
-class mapi_object_proxy _final {
+class mapi_object_proxy _zcp_final {
 public:
 	typedef _T		value_type;
 	typedef _T**	pointerpointer;
@@ -261,7 +235,7 @@ private:
 };
 
 template<>
-class mapi_object_proxy<IUnknown, IID_IUnknown> _final {
+class mapi_object_proxy<IUnknown, IID_IUnknown> _zcp_final {
 public:
 	typedef IUnknown	value_type;
 	typedef IUnknown**	pointerpointer;
