@@ -1,49 +1,38 @@
 /*
  * Copyright 2005 - 2015  Zarafa B.V. and its licensors
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation with the following
- * additional terms according to sec. 7:
- * 
- * "Zarafa" is a registered trademark of Zarafa B.V.
- * The licensing of the Program under the AGPL does not imply a trademark 
- * license. Therefore any rights, title and interest in our trademarks 
- * remain entirely with us.
- * 
- * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
- * in connection with Propagation and certain other acts regarding the Program.
- * In any case, if you propagate an unmodified version of the Program you are
- * allowed to use the term "Zarafa" to indicate that you distribute the Program.
- * Furthermore you may use our trademarks where it is necessary to indicate the
- * intended purpose of a product or service provided you use it in accordance
- * with honest business practices. For questions please contact Zarafa at
- * trademark@zarafa.com.
+ * as published by the Free Software Foundation.
  *
- * The interactive user interface of the software displays an attribution 
- * notice containing the term "Zarafa" and/or the logo of Zarafa. 
- * Interactive user interfaces of unmodified and modified versions must 
- * display Appropriate Legal Notices according to sec. 5 of the GNU Affero 
- * General Public License, version 3, when you propagate unmodified or 
- * modified versions of the Program. In accordance with sec. 7 b) of the GNU 
- * Affero General Public License, version 3, these Appropriate Legal Notices 
- * must retain the logo of Zarafa or display the words "Initial Development 
- * by Zarafa" if the display of the logo is not reasonably feasible for
- * technical reasons.
- * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
- *  
+ *
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifndef PLATFORM_H
 #define PLATFORM_H
 
+#if defined(__GNUC__) && !defined(__cplusplus)
+	/*
+	 * If typeof @a stays the same through a demotion to pointer,
+	 * @a cannot be an array.
+	 */
+#	define __array_size_check(a) BUILD_BUG_ON_EXPR(\
+		__builtin_types_compatible_p(__typeof__(a), \
+		__typeof__(DEMOTE_TO_PTR(a))))
+#else
+#	define __array_size_check(a) 0
+#endif
+#ifndef ARRAY_SIZE
+#	define ARRAY_SIZE(x) (sizeof(x) / sizeof(*(x)) + __array_size_check(x))
+#endif
+
 /* About _FORTIFY_SOURCE a.k.a. _BREAKIFY_SOURCE_IN_INSANE_WAYS
  *
  * This has the insane feature that it will assert() when you attempt
@@ -61,6 +50,9 @@
 #undef _FORTIFY_SOURCE
 #endif
 
+#if defined(WIN32) || defined(WINCE)
+  #include <zarafa/platform.win32.h>
+#else
 
   // We have to include this now in case select.h is included too soon.
   // Increase our maximum amount of file descriptors to 8192
@@ -79,14 +71,12 @@
   #ifdef HAVE_CONFIG_H
   #include "config.h"
   #endif
-  #include "platform.linux.h"
+  #include <zarafa/platform.linux.h>
+#endif
 
 #define ZARAFA_SYSTEM_USER		"SYSTEM"
 #define ZARAFA_SYSTEM_USER_W	L"SYSTEM"
 
-static const LONGLONG UnitsPerMinute = 600000000;
-static const LONGLONG UnitsPerHalfMinute = 300000000;
-
 /*
  * Platform independent functions
  */
@@ -125,14 +115,14 @@ struct tm* gmtime_safe(const time_t* timer, struct tm *result);
  */
 struct timespec GetDeadline(unsigned int ulTimeoutMs);
 
-double timespec2dbl(timespec t);
+double timespec2dbl(const struct timespec &t);
 
-bool operator ==(FILETIME a, FILETIME b);
-bool operator >(FILETIME a, FILETIME b);
-bool operator >=(FILETIME a, FILETIME b);
-bool operator <(FILETIME a, FILETIME b);
-bool operator <=(FILETIME a, FILETIME b);
-time_t operator -(FILETIME a, FILETIME b);
+bool operator ==(const FILETIME &, const FILETIME &);
+bool operator >(const FILETIME &, const FILETIME &);
+bool operator >=(const FILETIME &, const FILETIME &);
+bool operator <(const FILETIME &, const FILETIME &);
+bool operator <=(const FILETIME &, const FILETIME &);
+time_t operator -(const FILETIME &, const FILETIME &);
 
 /* convert struct tm to time_t in timezone UTC0 (GM time) */
 #ifndef __linux__
@@ -150,9 +140,15 @@ void	rand_get(char *p, int n);
 
 char *	get_password(const char *prompt);
 
-void	sleep_ms(unsigned int millis);
-
+#if defined (WIN32) && !defined (IGNORE_EXPORTS)
+ #ifdef ZARAFA_EXPORTS
+  #define ZARAFA_API __declspec(dllexport)
+ #else
+  #define ZARAFA_API __declspec(dllimport)
+ #endif
+#else
  #define ZARAFA_API
+#endif
 
 
 /**
@@ -176,5 +172,6 @@ void my_readahead(const int fd);
 void give_filesize_hint(const int fd, const off_t len);
 
 bool force_buffers_to_disk(const int fd);
+extern int ec_relocate_fd(int);
 
 #endif // PLATFORM_H
