@@ -1,6 +1,6 @@
 # shell include script
 
-ZARAFA_LANG="${ZARAFA_USERSCRIPT_LOCALE:-${LC_MESSAGES:-en_US}}"
+ZARAFA_LANG="${ZARAFA_USERSCRIPT_LOCALE:-${LC_MESSAGES:-C}}"
 PATH=$PATH:/usr/local/bin
 export ZARAFA_LANG PATH
 
